/// <reference types="react" />
import { RouteComponentProps } from 'dva/router';
import * as H from 'history';
import { StaticContext } from 'react-router';
export interface IRoute {
    path: string;
    component: () => Promise<{
        default: React.ComponentType<any>;
    }>;
    title?: string;
    routes?: IRoute[];
    exact?: boolean;
    wrappers?: IRoute['component'][];
    /** 访问该路由需要登录 */
    auth?: boolean;
    /** 缓存路由 */
    keepAlive?: boolean;
    redirect?: string;
}
export interface ILocation<S = H.LocationState, Q extends {
    [key in keyof Q]?: string;
} = {}> extends H.Location<S> {
    query: Q;
}
export interface IPath<S = H.LocationState> extends H.LocationDescriptorObject<S> {
    query?: Record<string, React.Key>;
}
export interface IHistory<S = H.LocationState, Q extends {
    [key in keyof Q]?: string;
} = {}> extends Omit<H.History<S>, 'push' | 'replace' | 'location'> {
    push: (path: string | IPath<S>, state?: S) => void;
    replace: (path: string | IPath<S>, state?: S) => void;
    location: ILocation<S, Q>;
}
export interface IRouteComponentProps<Params extends {
    [K in keyof Params]?: string;
} = {}, Query extends {
    [key in keyof Query]?: string;
} = {}, State = H.LocationState> extends RouteComponentProps<Params, StaticContext, State> {
    route: IRoute;
    routes: IRoute[];
    children?: React.ReactNode;
    history: IHistory<State, Query>;
    location: ILocation<State, Query>;
}
